@@ -3,7 +3,7 @@ package YAHC;
 use strict;
 use warnings;
 
-our $VERSION = '0.012';
+our $VERSION = '0.014';
 
 use EV;
 use Time::HiRes;
@@ -121,7 +121,7 @@ sub request {
     my $conn = {
         id          => $conn_id,
         request     => $request,
-        response    => { status_code => 0 },
+        response    => { status => 0 },
         attempt     => 0,
         retries     => $request->{retries} || 0,
         state       => YAHC::State::INITIALIZED(),
@@ -149,6 +149,7 @@ sub request {
     $self->{callbacks}{$conn_id} = \%callbacks;
     $self->{connections}{$conn_id} = $conn;
 
+    return $conn if $request->{_test}; # for testing purposes
     $self->_set_init_state($conn_id);
 
     # if user fire new request in a callback we need to update stop_condition
@@ -315,7 +316,7 @@ sub _set_init_state {
     my $watchers = $self->{watchers}{$conn_id};
     return $self->_set_completed_state($conn_id) unless $conn && $watchers;
 
-    $conn->{response} = { status_code => 0 };
+    $conn->{response} = { status => 0 };
     $conn->{state} = YAHC::State::INITIALIZED();
     _register_in_timeline($conn, "new state %s", _strstate($conn->{state})) if $conn->{keep_timeline};
     $self->_call_state_callback($conn, 'init_callback') if $conn->{has_init_callback};
@@ -640,14 +641,14 @@ sub _build_http_message {
         $CRLF,
         ($request->{method} || "GET") . " $path_and_qs " . ($request->{protocol} || "HTTP/1.1"),
         "Host: " . $conn->{selected_target}[0],
-        $request->{body} ? ("Content-Length: " . length($request->{body})) : (),
+        defined($request->{body}) ? ("Content-Length: " . length($request->{body})) : (),
         $request->{head} ? (
             map {
                 $request->{head}[2*$_] . ": " . $request->{head}[2*$_+1]
             } 0..$#{$request->{head}}/2
         ) : (),
         "",
-        $request->{body} ? $request->{body} : ""
+        defined($request->{body}) ? $request->{body} : ""
     );
 }
 
@@ -664,9 +665,9 @@ sub _parse_http_headers {
     }
 
     $conn->{response} = {
-        proto       => $proto,
-        status_code => $status_code,
-        headers     => \%headers,
+        proto  => $proto,
+        status => $status_code,
+        head   => \%headers,
     };
 
     return \%headers;
@@ -717,7 +718,7 @@ sub _register_error {
     my ($conn, $error, $format, @arguments) = @_;
     my $strerror = sprintf("$format", @arguments);
     $strerror =~ s/\s+$//g;
-    _register_in_timeline($conn, "error=$error ($strerror)") if $conn->{debug};
+    _register_in_timeline($conn, "error=$strerror ($error)") if $conn->{debug};
     push @{ $conn->{errors} ||= [] }, [ $error, $strerror, [ @{ $conn->{selected_target} } ], Time::HiRes::time ];
 }
 
@@ -779,7 +780,7 @@ YAHC - Yet another HTTP client
         path => '/',
         callback => sub {
             yahc_reinit_conn($_[0], { host => 'www.newtarget.com' })
-                if $_[0]->{response}{status_code} == 301;
+                if $_[0]->{response}{status} == 301;
         }
     });
 
@@ -822,6 +823,10 @@ YAHC uses following state machines for every connection:
                   +-----------------+
 
 
+=head1 REPOSITORY
+
+L<https://github.com/ikruglov/YAHC>
+
 =head1 AUTHORS
 
 Ivan Kruglov <ivan.kruglov@yahoo.com>
